<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.getfoundni.co.uk/
 * @since             1.1.3
 * @package           Notify_Gfni
 *
 * @wordpress-plugin
 * Plugin Name:       Notify By Get Found NI
 * Plugin URI:        notify-gfni
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           1.1.3
 * Author:            Ryan Hull
 * Author URI:        https://www.getfoundni.co.uk/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       notify-gfni
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'NOTIFY_GFNI_VERSION', '1.1.3' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-notify-gfni-activator.php
 */
function activate_notify_gfni() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-notify-gfni-activator.php';
	Notify_Gfni_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-notify-gfni-deactivator.php
 */
function deactivate_notify_gfni() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-notify-gfni-deactivator.php';
	Notify_Gfni_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_notify_gfni' );
register_deactivation_hook( __FILE__, 'deactivate_notify_gfni' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-notify-gfni.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_notify_gfni() {

	add_action('rest_api_init', function () {
		register_rest_route( 'notify-gfni/v1', 'latest-products',array(
					  'methods'  => 'GET',
					  'callback' => 'get_live_products'
			));
	  });


	/**
	 * Process the requests that comes to custom url.
	 */
	function get_live_products() { 

		$query = array(
			'post_type' => 'product',
			'posts_per_page' => -1,
			'post_status' => 'publish',
			'meta_query' => array(
				array(
					'key' => '_stock_status',
					'value' => 'instock'
				),
				array(
					'key' => '_backorders',
					'value' => 'no'
				),
			)
		);
		$wp_query = new WP_Query($query); 
		$data = [];
		foreach($wp_query->get_posts() as $post){ 
			$item = [];
			$product = wc_get_product( $post->ID ); 
			$item['id'] 			= $product->get_id();
			$item['title'] 			= $product->get_title();
			$item['price_html'] 	= $product->get_price_html();
			$item['image'] 	= get_the_post_thumbnail_url( $post->ID );
			$item['price'] 	= $product->get_price();
			$item['url'] 	= get_permalink( $post->ID ); 

			$data[] = $item; 
		} 
		 
		if (empty($data)) {
			return new WP_Error( 'empty_category', 'there are no instock products', array('status' => 404) );
		}
		
		$response = new WP_REST_Response($data);
		$response->set_status(200);
	
		return $response;
	}


	$plugin = new Notify_Gfni();
	$plugin->run();

}
run_notify_gfni();
